@@ -37,14 +37,16 @@ void Box_DB_Table_Relationships::init()
 {
   pack_start(m_AddDel);
   m_colName = m_AddDel.add_column(gettext("Name"));
+  m_colTitle = m_AddDel.add_column(gettext("Title"));
 
   m_colFromField = m_AddDel.add_column(gettext("From Field"), AddDelColumnInfo::STYLE_Choices);
   m_colToTable = m_AddDel.add_column(gettext("Table"), AddDelColumnInfo::STYLE_Choices);
   m_colToField = m_AddDel.add_column(gettext("To Field"), AddDelColumnInfo::STYLE_Choices);
 
   //Connect signals:
-  m_AddDel.signal_user_activated().connect(sigc::mem_fun(*this, &Box_DB_Table_Relationships::on_AddDel_user_activated));
-  m_AddDel.signal_user_changed().connect(sigc::mem_fun(*this, &Box_DB_Table_Relationships::on_AddDel_user_changed));
+  m_AddDel.signal_user_activated().connect(sigc::mem_fun(*this, &Box_DB_Table_Relationships::on_adddel_user_activated));
+  m_AddDel.signal_user_changed().connect(sigc::mem_fun(*this, &Box_DB_Table_Relationships::on_adddel_user_changed));
+  m_AddDel.signal_user_requested_delete().connect(sigc::mem_fun(*this, &Box_DB_Table_Relationships::on_adddel_user_requested_delete));
 
   show_all_children();
 }
@@ -56,14 +58,14 @@ Box_DB_Table_Relationships::~Box_DB_Table_Relationships()
 void Box_DB_Table_Relationships::fill_from_database()
 {
   Bakery::BusyCursor(*get_app_window());
-    
+
   Box_DB_Table::fill_from_database();
 
   //Get relationships from the document:
   Document_Glom::type_vecRelationships vecRelationships = m_pDocument->get_relationships(m_strTableName);
 
   m_AddDel.remove_all();
-  
+
   sharedptr<SharedConnection> sharedconnection = connect_to_server();
   if(sharedconnection)
   {
@@ -76,7 +78,7 @@ void Box_DB_Table_Relationships::fill_from_database()
     type_vecStrings vecTableNames_ustring(vecTableNames.begin(), vecTableNames.end());
     m_AddDel.set_column_choices(m_colToTable, vecTableNames_ustring);
 
-    //To Field choices are different for each row: set in on_AddDel_signal_user_activated.
+    //To Field choices are different for each row: set in on_adddel_signal_user_activated.
 
     //Add the relationships:
     for(Document_Glom::type_vecRelationships::iterator iter = vecRelationships.begin(); iter != vecRelationships.end(); iter++)
@@ -86,7 +88,10 @@ void Box_DB_Table_Relationships::fill_from_database()
        //Name:
        Gtk::TreeModel::iterator iterTree = m_AddDel.add_item(relationship.get_name());
        m_AddDel.set_value(iterTree, m_colName, relationship.get_name());
-       
+
+       //Title:
+       m_AddDel.set_value(iterTree, m_colTitle, relationship.get_title());
+
        //From Field:
        m_AddDel.set_value(iterTree, m_colFromField, relationship.get_from_field());
 
@@ -99,7 +104,7 @@ void Box_DB_Table_Relationships::fill_from_database()
 
     }
   }
-  
+
   fill_end();
 }
 
@@ -115,6 +120,7 @@ void Box_DB_Table_Relationships::save_to_document()
     {
       Relationship relationship;
       relationship.set_name(name);
+      relationship.set_title(m_AddDel.get_value(iter, m_colTitle));
       relationship.set_from_table(m_strTableName);
       relationship.set_from_field(m_AddDel.get_value(iter, m_colFromField));
       relationship.set_to_table(m_AddDel.get_value(iter, m_colToTable));
@@ -131,7 +137,7 @@ void Box_DB_Table_Relationships::save_to_document()
   Box_DB_Table::save_to_document();
 }
 
-void Box_DB_Table_Relationships::on_AddDel_user_changed(const Gtk::TreeModel::iterator& row, guint col)
+void Box_DB_Table_Relationships::on_adddel_user_changed(const Gtk::TreeModel::iterator& row, guint col)
 {
   if(col == m_colName)
   {
@@ -139,6 +145,14 @@ void Box_DB_Table_Relationships::on_AddDel_user_changed(const Gtk::TreeModel::it
     Glib::ustring new_name = m_AddDel.get_value(row, m_colName);
     if(!new_name.empty())
       m_AddDel.set_value_key(row, new_name);
+      
+    //Update the title, if there is none already:
+    Glib::ustring title = m_AddDel.get_value(row, m_colTitle);
+    if(title.empty())
+    {
+      title = Base_DB::util_title_from_string(new_name);
+      m_AddDel.set_value(row, m_colTitle, title);
+    }
   }
   else if(col == m_colToTable)
   {
@@ -150,11 +164,8 @@ void Box_DB_Table_Relationships::on_AddDel_user_changed(const Gtk::TreeModel::it
   set_modified();
 }
 
-void Box_DB_Table_Relationships::on_AddDel_user_activated(const Gtk::TreeModel::iterator& row, guint col)
+void Box_DB_Table_Relationships::on_adddel_user_activated(const Gtk::TreeModel::iterator& row, guint col)
 {
-
- g_warning("on_AddDel_user_activated setting to field col=%d", col);
- 
   if(col == m_colToField)
   {
     Bakery::BusyCursor(*get_app_window());
@@ -177,7 +188,6 @@ void Box_DB_Table_Relationships::on_AddDel_user_activated(const Gtk::TreeModel::
         //m_AddDel.set_column_choices(m_colToField, vecFields);
         //fill_from_database();
 
-        g_warning("setting to field col=%d, choices.size=%d", m_colToField, vecFields.size());
         m_AddDel.set_column_choices(m_colToField, vecFields);
       }
     }
@@ -185,4 +195,10 @@ void Box_DB_Table_Relationships::on_AddDel_user_activated(const Gtk::TreeModel::
   }
 }
 
+void Box_DB_Table_Relationships::on_adddel_user_requested_delete(const Gtk::TreeModel::iterator& rowStart, const Gtk::TreeModel::iterator& /* rowEnd TODO */)
+{
+  //Remove the row:
+  m_AddDel.remove_item(rowStart);
 
+  set_modified();
+}
