@@ -331,7 +331,7 @@ Gtk::TreeModel::iterator DbAddDel::add_item(const Gnome::Gda::Value& valKey)
 {
   if(!(get_model()))
     return Gtk::TreeModel::iterator();
-    
+
   Gtk::TreeModel::iterator result = get_next_available_row_with_add_if_necessary();
 
   if(result)
@@ -366,7 +366,7 @@ void DbAddDel::remove_all()
 }
 
 
-Gnome::Gda::Value DbAddDel::get_value(const Gtk::TreeModel::iterator& iter, guint col)
+Gnome::Gda::Value DbAddDel::get_value(const Gtk::TreeModel::iterator& iter, const LayoutItem_Field& layout_item)
 {
   Gnome::Gda::Value value;
 
@@ -376,8 +376,14 @@ Gnome::Gda::Value DbAddDel::get_value(const Gtk::TreeModel::iterator& iter, guin
 
     if(treerow)
     {
-      const guint col_real = col + get_count_hidden_system_columns();
-      treerow.get_value(col_real, value);
+      type_list_indexes list_indexes = get_column_index(layout_item);
+      if(!list_indexes.empty())
+      {
+        type_list_indexes::const_iterator iter = list_indexes.begin(); //Just get the first displayed instance of this field.
+
+        const guint col_real = *iter + get_count_hidden_system_columns();
+        treerow.get_value(col_real, value);
+      }
     }
   }
 
@@ -396,9 +402,9 @@ Gnome::Gda::Value DbAddDel::get_value_key_selected()
     return Gnome::Gda::Value();
 }
 
-Gnome::Gda::Value DbAddDel::get_value_selected(guint col)
+Gnome::Gda::Value DbAddDel::get_value_selected(const LayoutItem_Field& layout_item)
 {
-  return get_value(get_item_selected(), col);
+  return get_value(get_item_selected(), layout_item);
 }
 
 Gtk::TreeModel::iterator DbAddDel::get_item_selected()
@@ -561,24 +567,24 @@ void DbAddDel::construct_specified_columns()
   //Create the Gtk ColumnRecord:
 
   Gtk::TreeModel::ColumnRecord record;
-  
+
   //Hidden internal columns:
-  
+
   //We must recreate these standard modelcolumns, because we can not reuse them
   if(m_modelcolumn_key)
     delete m_modelcolumn_key; 
   m_modelcolumn_key = new Gtk::TreeModelColumn<Gnome::Gda::Value>;
-  
+
   //if(m_modelcolumn_placeholder)
   //  delete m_modelcolumn_placeholder;
   //m_modelcolumn_placeholder = new Gtk::TreeModelColumn<bool>;
-    
+
   record.add(*m_modelcolumn_key);
   //record.add(*m_modelcolumn_placeholder);
-    
+
   //Database columns:
   type_model_store::type_vec_fields fields;
-  {       
+  {
     type_vecModelColumns::size_type i = 0;
     for(type_ColumnTypes::iterator iter = m_ColumnTypes.begin(); iter != m_ColumnTypes.end(); ++iter)
     {
@@ -589,7 +595,7 @@ void DbAddDel::construct_specified_columns()
 
       record.add( *pModelColumn );
 
-      fields.push_back(iter->m_field);
+      fields.push_back(iter->m_field.m_field);
 
       i++;
     }
@@ -611,12 +617,12 @@ void DbAddDel::construct_specified_columns()
     DbAddDelColumnInfo& column_info = m_ColumnTypes[model_column_index];
     if(column_info.m_visible)
     {
-      const Glib::ustring column_name = column_info.m_field.get_title_or_name();
+      const Glib::ustring column_name = column_info.m_field.m_field.get_title_or_name();
       const Glib::ustring column_id = column_info.m_field.get_name();
 
       int cols_count = 0;
       Gtk::CellRenderer* pCellRenderer = 0;
-      switch(column_info.m_field.get_glom_type())
+      switch(column_info.m_field.m_field.get_glom_type())
       {
   /*
         case(DbAddDelColumnInfo::STYLE_Choices):
@@ -656,16 +662,16 @@ void DbAddDel::construct_specified_columns()
         default:
         {
           pCellRenderer = Gtk::manage( new Gtk::CellRendererText() );
-          
+
           break;
         }
       } //switch
-      
+
       ++cols_count;
-      
+
       //Add the ViewColumn
       treeview_append_column(column_name, *pCellRenderer, model_column_index);
-     
+
       if(column_info.m_editable)
       {
         Gtk::CellRendererText* pCellRenderer = dynamic_cast<Gtk::CellRendererText*>(m_TreeView.get_column_cell_renderer(view_column_index));
@@ -713,10 +719,10 @@ void DbAddDel::construct_specified_columns()
   m_TreeView.columns_autosize();
 }
 
-void DbAddDel::set_value(const Gtk::TreeModel::iterator& iter, guint col, const Gnome::Gda::Value& value)
+void DbAddDel::set_value(const Gtk::TreeModel::iterator& iter, const LayoutItem_Field& layout_item, const Gnome::Gda::Value& value)
 {
   //g_warning("DbAddDel::set_value begin");
-  
+
   InnerIgnore innerIgnore(this);
 
   if(!m_refListStore)
@@ -726,14 +732,18 @@ void DbAddDel::set_value(const Gtk::TreeModel::iterator& iter, guint col, const
     Gtk::TreeModel::Row treerow = *iter;
     if(treerow)
     {
-      guint treemodel_col = col + get_count_hidden_system_columns();
-      treerow.set_value(treemodel_col, value);
-
-      //Mark this row as not a placeholder because it has real data now.
-      if(!(GlomConversions::value_is_empty(value)))
+      type_list_indexes list_indexes = get_column_index(layout_item);
+      for(type_list_indexes::const_iterator iter = list_indexes.begin(); iter != list_indexes.end(); ++iter)
       {
-         //treerow.set_value(m_col_key, Glib::ustring("placeholder debug value setted"));
-         //treerow.set_value(m_col_placeholder, false);
+        guint treemodel_col = *iter + get_count_hidden_system_columns();
+        treerow.set_value(treemodel_col, value);
+
+        //Mark this row as not a placeholder because it has real data now.
+        if(!(GlomConversions::value_is_empty(value)))
+        {
+          //treerow.set_value(m_col_key, Glib::ustring("placeholder debug value setted"));
+          //treerow.set_value(m_col_placeholder, false);
+        }
       }
     }
 
@@ -744,9 +754,9 @@ void DbAddDel::set_value(const Gtk::TreeModel::iterator& iter, guint col, const
   //g_warning("DbAddDel::set_value end");
 }
 
-void DbAddDel::set_value_selected(guint col, const Gnome::Gda::Value& value)
+void DbAddDel::set_value_selected(const LayoutItem_Field& layout_item, const Gnome::Gda::Value& value)
 {
-  set_value(get_item_selected(), col, value);
+  set_value(get_item_selected(), layout_item, value);
 }
 
 void DbAddDel::remove_all_columns()
@@ -754,7 +764,7 @@ void DbAddDel::remove_all_columns()
   m_ColumnTypes.clear();
 }
 
-guint DbAddDel::add_column(const Field& field, bool editable, bool visible)
+guint DbAddDel::add_column(const LayoutItem_Field& field, bool editable, bool visible)
 {
   InnerIgnore innerIgnore(this); //Stop on_treeview_columns_changed() from doing anything when it is called just because we add a new column.
 
@@ -764,7 +774,7 @@ guint DbAddDel::add_column(const Field& field, bool editable, bool visible)
   column_info.m_visible = visible;
 
   //Make it non-editable if it is auto-generated:
-  if(field.get_field_info().get_auto_increment())
+  if(field.m_field.get_field_info().get_auto_increment())
     column_info.m_editable = false;
 
   m_ColumnTypes.push_back(column_info);
@@ -776,16 +786,37 @@ guint DbAddDel::add_column(const Field& field, bool editable, bool visible)
   //m_TreeView.set_model(m_refListStore);
 
   return m_ColumnTypes.size() - 1;
-  
 }
 
-Glib::ustring DbAddDel::get_column_field(guint column_index) const
+DbAddDel::type_list_indexes DbAddDel::get_column_index(const LayoutItem_Field& layout_item) const
 {
-  Glib::ustring result;
-  if(column_index < m_ColumnTypes.size())
-    result = m_ColumnTypes[column_index].m_field.get_name();
+  //TODO_Performance: Replace all this looping by a cache/map:
 
-  return result;
+  type_list_indexes list_indexes;
+
+  const Glib::ustring field_name = layout_item.get_name();
+  const Glib::ustring relationship_name = layout_item.get_relationship_name();
+
+  guint i = 0;
+  for(type_ColumnTypes::const_iterator iter = m_ColumnTypes.begin(); iter != m_ColumnTypes.end(); ++iter)
+  {
+    if( (iter->m_field.get_name() == field_name) && (iter->m_field.get_relationship_name() == relationship_name) )
+    {
+      list_indexes.push_back(i);
+    }
+
+    ++i;
+  }
+
+  return list_indexes;
+}
+
+LayoutItem_Field DbAddDel::get_column_field(guint column_index) const
+{
+  if(column_index < m_ColumnTypes.size())
+    return m_ColumnTypes[column_index].m_field;
+
+  return LayoutItem_Field();
 }
 
 bool DbAddDel::get_prevent_user_signals() const
@@ -1078,7 +1109,7 @@ void DbAddDel::on_treeview_cell_edited(const Glib::ustring& path_string, const G
       }
     }
 
-    const Field::glom_field_type field_type = m_ColumnTypes[model_column_index].m_field.get_glom_type();
+    const Field::glom_field_type field_type = m_ColumnTypes[model_column_index].m_field.m_field.get_glom_type();
     if(field_type != Field::TYPE_INVALID) //If a field type was specified for this column.
     {
       //Make sure that the entered data is suitable for this field type:
@@ -1459,14 +1490,14 @@ void DbAddDel::set_value_key(const Gtk::TreeModel::iterator& iter, const Gnome::
   if(iter)
   {
     Gtk::TreeModel::Row row = *iter;
-  
+
     if(!(GlomConversions::value_is_empty(value)))
     {
       //This is not a placeholder anymore, if it every was:
       m_refListStore->set_is_placeholder(iter, false);
       //row[*m_modelcolumn_placeholder] = false;
     }
-  
+
     row[*m_modelcolumn_key] = value;
   }
 }
@@ -1505,7 +1536,7 @@ bool DbAddDel::get_view_column_index(guint model_column_index, guint& view_colum
 
   if(model_column_index >=  m_ColumnTypes.size())
     return false;
-    
+
   if( !(m_ColumnTypes[model_column_index].m_visible) )
     return false;
 
@@ -1537,27 +1568,28 @@ void DbAddDel::set_key_field(const Field& field)
 
 void DbAddDel::treeviewcolumn_on_cell_data(Gtk::CellRenderer* renderer, const Gtk::TreeModel::iterator& iter, int model_column_index)
 {
-  Gnome::Gda::Value value = get_value(iter, model_column_index);
-  
+  const guint col_real = model_column_index + get_count_hidden_system_columns();
+  Gtk::TreeModel::Row treerow = *iter;
+  Gnome::Gda::Value value;
+  treerow->get_value(col_real, value);
+
   DbAddDelColumnInfo& column_info = m_ColumnTypes[model_column_index];
-  switch(column_info.m_field.get_glom_type())
+  switch(column_info.m_field.m_field.get_glom_type())
   {
     case(Field::TYPE_BOOLEAN):
     {
       Gtk::CellRendererToggle* pDerived = dynamic_cast<Gtk::CellRendererToggle*>(renderer);
       pDerived->set_active( value.get_bool() ); 
-  
+
       break;
     }
     default:
     {
       //TODO: Maybe we should have custom cellrenderers for time, date, and numbers.
       Gtk::CellRendererText* pDerived = dynamic_cast<Gtk::CellRendererText*>(renderer);
-      
-      Glib::ustring debugtext = GlomConversions::get_text_for_gda_value(column_info.m_field.get_glom_type(), value);
-      
-      pDerived->property_text() = GlomConversions::get_text_for_gda_value(column_info.m_field.get_glom_type(), value);
-  
+
+      pDerived->property_text() = GlomConversions::get_text_for_gda_value(column_info.m_field.m_field.get_glom_type(), value);
+
       break;
     } 
   }
